==> grizzly-websockets-2.3.1-sources.jar: org/glassfish/grizzly/websockets/DummyBroadcaster.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.grizzly.websockets;

/**
 * The default {@link Broadcaster}, which iterates over set of clients and sends
 * the same text of binary message separately to each client.
 * So the text/binary -> websocket-frame transformation is being done for
 * each client separately.
 * 
 * @author Alexey Stashok
 */
public class DummyBroadcaster implements Broadcaster {

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final String text) {
        
        for (WebSocket websocket : recipients) {
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                
                try {
                    websocket.send(text);
                } catch (WebSocketException e) {
                }
            }
        }
    }
    
    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final byte[] binary) {
        
        for (WebSocket websocket : recipients) {
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                
                try {
                    websocket.send(binary);
                } catch (WebSocketException e) {
                }
            }
        }
    }    

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcastFragment(final Iterable<? extends WebSocket> recipients,
            final String text, final boolean last) {
        for (WebSocket websocket : recipients) {
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                
                try {
                    websocket.stream(last, text);
                } catch (WebSocketException e) {
                }
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcastFragment(final Iterable<? extends WebSocket> recipients,
            final byte[] binary, final boolean last) {
        
        for (WebSocket websocket : recipients) {
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                
                try {
                    websocket.stream(last, binary, 0, binary.length);
                } catch (WebSocketException e) {
                }
            }
        }
    }
    
    
}

==> grizzly-websockets-2.4.3.1-sources.jar: org/glassfish/grizzly/websockets/DummyBroadcaster.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly.websockets;

/**
 * The default {@link Broadcaster}, which iterates over set of clients and sends
 * the same text of binary message separately to each client.
 * So the text/binary -> websocket-frame transformation is being done for
 * each client separately.
 * 
 * @author Alexey Stashok
 */
public class DummyBroadcaster implements Broadcaster {

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final String text) {
        
        for (WebSocket websocket : recipients) {
            if (websocket.isConnected()) {
                try {
                    websocket.send(text);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }
    
    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final byte[] binary) {
        
        for (WebSocket websocket : recipients) {
            if (websocket.isConnected()) {
                try {
                    websocket.send(binary);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }    

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcastFragment(final Iterable<? extends WebSocket> recipients,
            final String text, final boolean last) {
        for (WebSocket websocket : recipients) {
            if (websocket.isConnected()) {
                try {
                    websocket.stream(last, text);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcastFragment(final Iterable<? extends WebSocket> recipients,
            final byte[] binary, final boolean last) {
        
        for (WebSocket websocket : recipients) {
            if (websocket.isConnected()) {
                try {
                    websocket.stream(last, binary, 0, binary.length);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }
    
    
}
